@@ -129,15 +129,15 @@ public:
 
     /******************************************************/
 
-    Q_PROPERTY(bool insidePhotoSphere READ getInsidePhotoSphere WRITE setInsidePhotoSphere NOTIFY insidePhotoSphereChanged)
-    void setInsidePhotoSphere(bool val);
-    Q_INVOKABLE bool getInsidePhotoSphere ();
+    Q_PROPERTY(bool showingPhotoSphere READ getShowingPhotoSphere WRITE setShowingPhotoSphere NOTIFY showingPhotoSphereChanged)
+    void setShowingPhotoSphere(bool val);
+    Q_INVOKABLE bool getShowingPhotoSphere ();
 
     /******************************************************/
 
-    Q_PROPERTY(bool hasPhotoSphere READ getHasPhotoSphere WRITE setHasPhotoSphere NOTIFY hasPhotoSphereChanged)
-    void setHasPhotoSphere(bool val);
-    Q_INVOKABLE bool getHasPhotoSphere();
+    Q_PROPERTY(bool isMotionPhoto READ getIsMotionPhoto WRITE setIsMotionPhoto NOTIFY isMotionPhotoChanged)
+    void setIsMotionPhoto(bool val);
+    Q_INVOKABLE bool getIsMotionPhoto();
 
     /******************************************************/
 
@@ -176,8 +176,8 @@ private:
         m_haveScreenshots = false;
         m_settingUpdate.clear();
         m_startupCheck = 0;
-        m_hasPhotoSphere = false;
-        m_insidePhotoSphere = false;
+        m_isMotionPhoto = false;
+        m_showingPhotoSphere = false;
         m_barcodeDisplayed = false;
         m_colorProfiles.clear();
         m_whichContextMenusOpen.clear();
@@ -206,8 +206,8 @@ private:
 
     int m_startupCheck;
 
-    bool m_hasPhotoSphere;
-    bool m_insidePhotoSphere;
+    bool m_showingPhotoSphere;
+    bool m_isMotionPhoto;
 
     bool m_barcodeDisplayed;
 
@@ -235,8 +235,8 @@ Q_SIGNALS:
     void slideshowRunningChanged();
     void faceTaggingChanged();
 
-    void insidePhotoSphereChanged();
-    void hasPhotoSphereChanged();
+    void showingPhotoSphereChanged();
+    void isMotionPhotoChanged();
 
     void barcodeDisplayedChanged();
 
@@ -262,8 +262,6 @@ Q_SIGNALS:
     void keyPress(int key, int modifiers);
     void executeInternalCommand(QString cmd);
 
-    void enterPhotoSphere();
-
     void showNotificationMessage(QString msg);
 
     // these are called by various qml elements to trigger mouse shortcuts
