@@ -75,6 +75,7 @@
 #include <scripts/pqc_scriptsshareimgur.h>
 #include <scripts/pqc_scriptswallpaper.h>
 #include <scripts/pqc_scriptschromecast.h>
+#include <scripts/pqc_scriptsundo.h>
 
 #ifdef PQMGRAPHICSMAGICK
 #include <GraphicsMagick/Magick++.h>
@@ -298,6 +299,7 @@ int main(int argc, char *argv[]) {
     qmlRegisterSingletonInstance("PQCScriptsWallpaper", 1, 0, "PQCScriptsWallpaper", &PQCScriptsWallpaper::get());
     qmlRegisterSingletonInstance("PQCLocation", 1, 0, "PQCLocation", &PQCLocation::get());
     qmlRegisterSingletonInstance("PQCScriptsChromeCast", 1, 0, "PQCScriptsChromeCast", &PQCScriptsChromeCast::get());
+    qmlRegisterSingletonInstance("PQCScriptsUndo", 1, 0, "PQCScriptsUndo", &PQCScriptsUndo::get());
 
     // these are used pretty much everywhere, this avoids having to import it everywhere
     engine.rootContext()->setContextProperty("PQCLook", &PQCLook::get());
